<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output method="xml" encoding="UTF-8"
    doctype-system="http://www.springframework.org/dtd/spring-beans.dtd"
    doctype-public="-//SPRING//DTD BEAN//EN"
    cdata-section-elements="beans" />

  <!-- Default stage table names -->
	<xsl:variable name="ST_TEAM_MEMBERSHIP">DS_TEAM_MEMBERSHIPS</xsl:variable>

  <!-- Staging Field names -->
	<xsl:variable name="team_key_field">team_key</xsl:variable>
	<xsl:variable name="member_key_field">member_key</xsl:variable>
	<xsl:variable name="member_sequence_number_field">member_sequence_number</xsl:variable>
	<xsl:variable name="member_sub_type_field">member_sub_type</xsl:variable>
	<xsl:variable name="member_type_field">member_type</xsl:variable>
  
	<!-- Row Synchronizers -->
	<xsl:variable name="team_membership_row_synchronizer">com.invoqsystems.apex.datasynchronizer.processor.EnterpriseTeamMembershipTeamSynchronizerImpl</xsl:variable>

	<!-- Team Membership -->
	<xsl:template match="team_membership">
		<bean>
			<xsl:attribute name="class">

      <xsl:choose>
        <xsl:when test="$direction=$to_alarmpoint">
          <xsl:call-template name="choose_table_synchronizer_class">        
            <xsl:with-param name="override" select="$ent_tm_membership_tsync_class"/>
          </xsl:call-template>
        </xsl:when>
  			<xsl:otherwise>
          <xsl:call-template name="choose_table_synchronizer_class">        
            <xsl:with-param name="override" select="$staging_tsync_class"/>
          </xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>

			</xsl:attribute>
			<xsl:call-template name="inject_staging_datasource" />
			<xsl:call-template name="choose_staging_table_name">
			  <xsl:with-param name="default_name" select="$ST_TEAM_MEMBERSHIP" />
			</xsl:call-template>
			<xsl:call-template name="include_audit_service"/>
			<property name="dataSynchronizationService">
				<ref bean="dataSyncTeamMembershipService" />
			</property>
			<xsl:call-template name="inject_report_keeper"/>
			<!-- Row Synchronizer -->
			<xsl:call-template name="row_synchronizer">
				<xsl:with-param name="data_synchronization_service">dataSyncTeamMembershipService</xsl:with-param>
				<xsl:with-param name="default_table" select="$ST_TEAM_MEMBERSHIP" />
				<xsl:with-param name="sync_class" select="$team_membership_row_synchronizer"/>
				<xsl:with-param name="row_marker">rowStagingTableTeamMemberMarker</xsl:with-param>
			</xsl:call-template>
		</bean>
	</xsl:template>

  <!-- Field Level -->
	<!-- Note that if no mapper class is specified then a match will be done on type, the default mapper is String -->
	<xsl:template match="team_key">
		<xsl:call-template name="call_fields">
			<xsl:with-param name="model_property_name">team</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="member_key">
		<xsl:call-template name="call_fields">
			<xsl:with-param name="model_property_name">member</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="member_type">
		<xsl:call-template name="call_fields">
			<xsl:with-param name="model_property_name">memberType</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="member_sub_type">
		<xsl:call-template name="call_fields">
			<xsl:with-param name="model_property_name">memberSubType</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="member_sequence_number">
		<xsl:call-template name="call_fields">
			<xsl:with-param name="model_property_name">sequenceNumber</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

</xsl:stylesheet>
